摔跤吧！爸爸 (豆瓣)
Description: 摔跤吧！爸爸电影简介和剧情介绍,摔跤吧！爸爸影评、图片、预告片、影讯、论坛、在线购票
Keywords: 摔跤吧！爸爸,Dangal,摔跤吧！爸爸影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.37豆瓣电影Top250

# 摔跤吧！爸爸 Dangal (2016)

导演: 涅提·蒂瓦里
编剧: 比于什·古普塔 / 施热亚·简 / 尼基尔·麦罗特拉 / 涅提·蒂瓦里
主演: 阿米尔·汗 / 法缇玛·萨那·纱卡 / 桑亚·玛荷塔 / 阿帕尔夏克提·库拉那 / 沙克希·坦沃 / 塞伊拉·沃西 / 苏哈妮·巴特纳格尔 / 里特维克·萨霍里 / 吉里什·库卡尼
类型: 剧情 / 家庭 / 传记 / 运动
制片国家/地区: 印度
语言: 印地语 / 英语
上映日期: 2017-05-05(中国大陆) / 2016-12-23(印度)
片长: 161分钟(印度) / 140分钟(中国大陆)
又名: 我和我的冠军女儿(台) / 打死不离3父女(港) / 摔跤吧！老爸 / 摔跤家族 / दंगल / Wrestling Competition
IMDb: tt5074352
豆瓣评分
引用
9.0
1497172人评价
5星
59.6%
4星
32.9%
3星
6.8%
2星
0.5%
1星
0.2%
好于 99% 运动片
好于 98% 传记片
想看 看过
评价:
推荐

## 摔跤吧！爸爸的剧情简介 · · · · · ·

马哈维亚（阿米尔·汗 Aamir Khan 饰）曾经是一名前途无量的摔跤运动员，在放弃了职业生涯后，他最大的遗憾就是没有能够替国家赢得金牌。马哈维亚将这份希望寄托在了尚未出生的儿子身上，哪知道妻子接连给他生了两个女儿，取名吉塔（法缇玛·萨那·纱卡 Fatima Sana Shaikh 饰）和巴比塔（桑亚·玛荷塔 Sanya Malhotra 饰）。让马哈维亚没有想到的是，两个姑娘展现出了杰出的摔跤天赋，让他幡然醒悟，就算是女孩，也能够昂首挺胸的站在比赛场上，为了国家和她们自己赢得荣誉。
就这样，在马哈维亚的指导下，吉塔和巴比塔开始了艰苦的训练，两人进步神速，很快就因为在比赛中连连获胜而成为了当地的名人。为了获得更多的机会，吉塔进入了国家体育学院学习，在那里，她将面对更大的诱惑和更多的选择。 ©豆瓣

## 摔跤吧！爸爸的演职员 · · · · · · ( 全部 17 )

- 涅提·蒂瓦里 导演
- 阿米尔·汗 饰 马哈维亚·辛格·珀尕 Mahavir Singh Phogat
- 法缇玛·萨那·纱卡 饰 吉塔·珀尕 Geeta Phogat
- 桑亚·玛荷塔 饰 芭比塔·库马尔·珀尕 Babita Kumar Phogat
- 阿帕尔夏克提·库拉那 饰 奥姆卡尔(侄子) Omkar
- 沙克希·坦沃 饰 达雅·考尔 Daya Kaur

## 摔跤吧！爸爸的视频和图片 · · · · · · ( 预告片9 | 添加视频评论 | 图片920 · 添加 )

## 摔跤吧！爸爸的获奖情况 · · · · · · ( 全部 )

- 第6届豆瓣电影年度榜单
- 2010s电影(提名)

- 第4届豆瓣电影年度榜单
- 评分最高的外语电影

- 第4届豆瓣电影年度榜单
- 最受关注的院线电影(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  当幸福来敲门

  肖申克的救赎

  阿甘正传

  三傻大闹宝莱坞

  贫民窟的百万富翁

  国王的演讲

  寻梦环游记

  奇迹男孩

  心灵捕手

  饮食男女

我要写短评

## 摔跤吧！爸爸的短评 · · · · · · ( 全部 307229 条 )

热门 / 最新 / 好友

### 20642 有用 有点迷人 看过 2017-01-04 21:54:29

阿米尔一人饰演男主角19、29、55岁三个人生段。他首先完成了19岁的戏，然后疯狂增肥，一个月时间变成了体重194斤的55胖大爷，拍完老年戏后，又用5个月的时间疯狂减肥，回去拍29的戏！所以：为什么要这么折腾自己？直接拍完29再拍55不就好了？阿米尔说：那样我就没有动力瘦回去了！

### 16492 有用 江湖骗子想吃蛋糕 看过 2017-04-16 17:24:12

关于本片价值观－不看社会背景就评判三观就是耍流氓。在印度的社会状况下，女性是没有自由选择职业的氛围的，先破才能立。就像片中父亲对女儿说的－你不是在为你一个人战斗，你要让千千万万的女性看到女生并不是只能相夫教子。最后，这场斗争的意义早已超脱出父亲一己的梦想，升华了呀。

### 11445 有用 同志亦凡人中文站 看过 2016-12-23 17:50:46

根据真人真事改编，讲述印度一块女子摔跤金牌的诞生。剧情热血逗乐，竞技惊心动魄，挑不出什么毛病的宝莱坞电影，父女情尽在不言中。阿米尔·汗太敬业了，为了一闪而过的几秒就把自己的身材从肥胖练成魔鬼，好演员都是用生命在演戏啊～

### 16069 有用 仰望星空の派 看过 2016-12-24 07:02:54

这么好的一部电影。。弄得这踏马什么破译名。。听起来像儿童片似的。。

### 7351 有用 踢迩达 看过 2017-01-18 00:46:54

豆瓣文青们可能已经成功被白左的西方政治正确洗脑了：不放在具体语境下，以西方女权衡量一切本来就是一种偏见和武断。在整体状况还不如中国的印度，本片已经适当地展现了一种进步的女性生活方式，即便在父权的引导之下。让符号化的解读蒙蔽影片传达的真情实感，令人感到可悲。

> 更多短评 307229条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 摔跤吧！爸爸的影评 · · · · · · ( 全部 8487 条 )

热门 / 最新 / 好友
microuniverse 2017-01-12 23:35:03

## 国家金牌意识的觉醒和真实的印度妇女地位

2016 年里约奥运会，joseph schooling 击败菲尔普斯，拿下了新加坡建国以来的首个金牌。在我们眼里，奥运金牌早已不是什么稀罕物，而在只有五百万人口的弹丸新加坡，Schooling就是国家英雄一般。 回国后，新加坡给他安排一场庆祝胜利的游行。Schooling站在敞篷双层巴士的最上层... (展开)
8999 282 466回应 收起
Amberose 2017-01-09 06:39:34

## 一枚改变历史的金牌与现实数据

这篇影评可能有剧透

电影散场后，我急匆匆走出放映厅，打开手机查询电影中人物的真实故事 Geeta Phogat：第一位赢得英联邦运动会的印度摔跤选手（2010, 55公斤级），也是第一位取得夏季奥林匹克运动会参赛资格的女性摔跤选手（2012） Babita Kumari：在2014格拉斯哥英联邦运动会55公斤级女子自由式... (展开)
4767 137 149回应 收起
奋斗的burning 2017-01-15 11:24:19

## 驳——某位论《摔跤吧！爸爸》是一部令人恶心的作品

你说这是一部带剧毒的电影，很高兴，我看了还能头脑清醒的站在这儿和你好好说道说道。 不知道你有没有认真看完这部电影，哦，是“如坐针毡”呢，我想是没有仔仔细细看过吧。大概才看了十来分钟就兴奋得不知所以吧，哇，又发现一个好的论点，跟发现了一座金矿似的。 在你沉浸... (展开)
4258 230 517回应 收起
Vamei 2017-01-22 00:36:46

## 选择不容易

电影里，大女儿Geeta经过父亲的训练，第一次上赛场。四个男孩子一字排开，有的瘦弱，有的精壮，任由Geeta挑选。当然，所有观众都相信，即使最弱的男孩子，也能赢Geeta这个女孩儿。但Geeta选择了最强的对手。 就像全剧所有的摔跤场景一样，随后的搏斗真实而精彩。对手一开始不屑... (展开)
1966 62 81回应 收起
刘星花园 2017-05-07 00:54:41

## 我愿用尽一切高尚的词汇去吹捧阿米尔汗，因为他值得

这篇影评可能有剧透

曾经看过阿米尔汗做的一个访谈类节目——《真相访谈》，在那个访谈中，有将近一半的时间在描绘印度女性在成长过程中会遭遇的种种不幸：杀女婴、儿童性侵、强奸、包办婚姻、巨额嫁妆、家庭暴力……越看越会觉得生为一个印度女性实在是太凄苦了。一般来讲，人在伤心想哭的时候心... (展开)
1511 23 126回应 收起
谢飞导演 2017-05-11 16:35:09

## 一部印度电影的启示

这些年常到南亚国家去参加电影节和讲学，对那里的电影也就看得多了些，有了些感情。为此专门到影院去看了这部口碑爆棚的印度电影《摔跤吧，爸爸！》。中规中矩的体育励志片，值三颗星，主演阿米尔汗为角色增肥、减肥50多斤的敬艺精神值得增加另一颗星。 我们在赞美印度电影的高... (展开)
383 82 67回应 收起
柏邦妮 2017-06-21 19:50:02

## 没有写出来的地方才是深渊

老有人讨论，《摔跤吧爸爸》到底是不是进步，到底是不是女权，爸爸给的是不是爱。我觉得这事儿挺容易想的。 在女人都是女奴的环境里，“像个男人”就是进步，就是更好的选择。因为没有什么选择。在女人也是人的环境里，“像她自己”是进步，因为选择更多了。 打个比方，文革... (展开)
439 19 26回应 收起
风间隼 2017-05-08 13:56:05

## 让印度电影给我们上一课

这篇影评可能有剧透

如果说今日的中国观众对于国外电影有什么品牌忠诚度的话，好莱坞特效大片称第一，日本动画算第二，那第三，就该数一个印度人撑起的一片天了，那就是阿米尔•汗的电影。 从《地球上的星星》、《三个傻瓜》、《PK》到这部《摔跤吧！爸爸》，男神在中国的好口碑那是一步一个脚... (展开)
686 41 114回应 收起
非关文字 2017-05-05 19:02:55

## 你要成为冠军，还是输的别太难看？

教练说：不要输的太难看。 爸爸说：你不会输！ 教练说：至少要拿块奖牌。 爸爸说：你注定是冠军！ 教练说：你已经领先了，注意防守。 爸爸说：忘掉领先，保持进攻！ 教练说：有些人，注定不是打国际比赛的料。 爸爸说：你输掉的，是本该你赢的比赛。 教练说：现在你至少可以有... (展开)
760 42 39回应 收起
Yuki 2017-05-05 21:51:26

## “爸爸不是每一次都会救你，这一次，你要靠自己。”

这篇影评可能有剧透

超五星的电影，维持了阿米尔汗一贯的水准。尽管米叔本人在上次的北京见面会上一直强调自己是很有福气参与过这么多优秀的电影，一部好的电影离不开编剧、导演、监制、美术、灯光等等很多工种的协作，才能最后完成。 我虽认可这个说法但仍认为米叔的存在和演绎赋予了每一部电影活... (展开)
556 21 23回应 收起

> 更多影评 8487篇

添加新讨论

## 讨论区 · · · · · ·

印度都开始拍女权电影了，什么时候轮到我们？ | 来自安Chaney | 275 回应 | 2022-11-06 22:05:02
还好我生活在中国 | 来自米粒 |  | 2022-11-06 14:58:34
这是一部通俗易懂的励志片，超赞 | 来自豆友212456662 |  | 2022-10-30 04:45:33
田园女权，请问你们凭啥说那父亲？ | 来自noob | 11 回应 | 2022-10-29 20:04:08
分还是过高了 | 来自mrgame | 4 回应 | 2022-10-22 20:51:22

> 去这部影片的讨论区（全部830条）

## 关于《摔跤吧！爸爸》的问题 · · · · · · ( 全部126个 )

- 剧中她们是真摔吗？感觉非常专业啊？ 15人回答
- 自己不爱摔跤，就假设天下所有女性都不喜欢摔跤，并把练摔跤看做来自男权的迫害，这才是真正... 47人回答

> 全部126个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)
- 10分钟就让你【欲罢不能】的高分电影 (梭马飞鱼)
- IMDB TOP 250 UPDATE 20221113 (lelechen)

## 谁在看这部电影 · · · · · ·

- Y
  刚刚 看过
- 子时当归
  刚刚 看过
- Victor
  1分钟前 看过

3289986人看过 / 199924人想看

订阅摔跤吧！爸爸的评论:
feed: rss 2.0